classdef CAcqSetupView < CGuiView & CBlockablePanel
    %CACQSETUPVIEW   NiHu.Lab gui panel for setting acquisition setup
    %   CACQSETUPVIEW sets acquisition setup parameters, such a sampling
    %   frequency and number of samples.
    %
    % Example:
    % AS = CAcqSetup;
    % AV = CAcqSetupView(gcf, AS);
    %
    % See also CAcqSetup
    
    properties (Access = private)
        hTable      % GUI table handle
    end
	
    methods
        function obj = CAcqSetupView(parent, hData)
            obj = obj@CBlockablePanel(parent, 'ACQSETUP_PANEL');
            obj = obj@CGuiView(hData, {'Fs', 'nSamples'});
            obj.InitObject();
            obj.refresh();
        end
        
        function refresh(obj)
            %REFRESH Called when gui must be redrawn
            set(obj.hTable, 'Data', {round(obj.hData.Fs), obj.hData.nSamples, obj.hData.T});
        end
        
        function FsCallback(obj)
            %FSCALLBACK Called when Sampling Frequency is modified
            D = get(obj.hTable, 'Data');
            obj.hData.Fs = D{1};
            obj.hData.nSamples = D{2};
        end
    end

    methods (Access = private)
        function InitObject(obj)
            FreqStr = strtrim(cellstr(num2str(obj.hData.FsRange(:), '%.0f '))');
            NStr = strtrim(cellstr(num2str(obj.hData.nSamplesRange(:)))');
            obj.hTable = uitable('Parent', obj.hPanel, ...
                'ColumnName', {'Fs [Hz]', 'N samp.', 'T [s]'}, ...
                'ColumnEditable', [true, true, false], ...
                'ColumnFormat', {FreqStr, NStr, 'numeric'}, ...
                'ColumnWidth', {67 67 67}, ...
                'RowName', [], ...
                'Data', {0, 0, 0}, ...  % placeholder for function extent
                'CellEditCallback', @(src, event)FsCallback(obj));
            e = extent(obj.hTable);
            set(obj.hTable, 'Position', e);
            GuiLayout.ApplyLayout(obj.hPanel, {{obj.hTable, [0 0]}});
        end
    end
end
