classdef CAmpChannel < handle
    %CAMPCHANNEL NiHu.Lab class for amplifier channel handling
    %
    % Example:
    %  Amp = CAmplifier('PCB', '4228A', 1234, 8, true, [1 10 100]);
    %  AmpCh = CAmpChannel(Amp, 1, 10);
    %  AmpCh.PushButton();
    %
    % See also: CAmplifier
    
    properties (SetAccess = immutable)
        Amplifier   % handle to CAmplifier object
    end
    
    properties
        ChNum       % channel index on the amplifier
        Amplification   % Amplification value
    end
    
    properties (Dependent = true)
        Name    % Name of channel (Name of amplifier + Ch number)
    end
    
    methods
        function obj = CAmpChannel(amp, num, amplification)
            if nargin < 3
                amplification = 1;
            end
            if nargin < 2
                num = 1;
            end
            obj.Amplifier = amp;
            obj.ChNum = num;
            obj.Amplification = amplification;
        end
        
        function name = get.Name(obj)
            if obj.Amplifier.NumChannels == 1
                name = strtrim(obj.Amplifier.Name);
            else
                name = strtrim(sprintf('%s Ch%d', obj.Amplifier.Vendor, obj.ChNum));
            end
        end
        
        function PushButton(obj)
            %PUSHBUTTON function called on pushing the channel's button
            % change amplification to the next value in the array [1 10 100]
            
            idx = find(obj.Amplification == obj.Amplifier.Amplifications, 1, 'first');
            idx = mod(idx, length(obj.Amplifier.Amplifications))+1;
            obj.Amplification = obj.Amplifier.Amplifications(idx);
        end
    end % of public methods
end % of classdef
