classdef CAverage < handle & CCopyableObject
    %CAVERAGE  NiHu.Lab class for averaging parameters
    
    properties (SetObservable = true)
        nAverage    % number of averages
        nPre        % number of pre measurement cycles
        nPost       % number of post measurement cycles
    end
    
    properties (Transient = true, SetObservable = true)
        isPre       % shows whether pre and post averaging is allowed or not
        iAver       % curren averaging cycle
    end
    
    methods
        function obj = CAverage(isPre)
            % pre cycle is enabled by default
            if nargin == 0
                obj.isPre = true;
            else
                obj.isPre = isPre;
            end
            % default averaging and pre values
            obj.nAverage = 5;
            if obj.isPre
                obj.nPre = 1;
            else
                obj.nPre = 0;
            end
            obj.nPost = 0;
        end
        
        function set.iAver(obj, iAver)
            obj.iAver = iAver;
        end
        
        function reset(obj)
            %RESET set number of averages to zero
            obj.iAver = 0;
        end
        
        function step(obj)
            %STEP increment number of averages
            if obj.iAver == obj.nPre + obj.nPost + obj.nAverage
                error('CAverage:step', 'averaging overflow');
            end
            obj.iAver = obj.iAver+1;
        end
    end % of public methods
end % of classdef
