classdef CDistSignalView < CGuiView & CBlockablePanel
    %CDISTSIGNALVIEW NiHu.Lab panel for harmonic distortion signal selection
    %
    % See also: CDistSignal, CDistorsion

    properties
        hType       % signal Type handle
        hTable      % table handle where the information is stored
    end
    
    methods
        function obj = CDistSignalView(parent, hData)
            obj = obj@CBlockablePanel(parent, 'DISTORTION_SIGNAL_PANEL');
            obj = obj@CGuiView(hData, {'Amplitude', 'Flim', 'nFreq'});
            obj.InitObject();
            obj.refresh();
        end
        
        function refresh(obj)
            %REFRESH Called when the GUI needs to be updated
            
            Data = {obj.hData.Amplitude, obj.hData.Flim(1), obj.hData.Flim(2), obj.hData.nFreq};
            CN = {'Amp [V]', 'F1 [Hz]', 'F2 [Hz]', 'N [-]'};
            CF = {'numeric', 'numeric', 'numeric', 'numeric'};
            set(obj.hTable, 'Data', Data, 'ColumnName', CN, 'ColumnFormat', CF);
        end
        
        function TableCallback(obj)
            %TABLECALLBACK Called when the table is modified
            
            Data = get(obj.hTable, 'Data');
            obj.hData.Amplitude = Data{1};
            obj.hData.Flim = [Data{2} Data{3}];
            obj.hData.nFreq = Data{4};
        end
    end % of public methods
    
    methods (Access = private)
        function InitObject(obj)
            obj.hTable = uitable('Parent', obj.hPanel, 'RowName', [],...
                'Units', 'Pixels', 'ColumnWidth', {50 50 50 50}, ...
                'ColumnEditable', true(1,4), ...
                'CellEditCallback', @(src, event)TableCallback(obj), ...
                'Data', {1 2 3 4}, 'Position', [0, 0, 100, 10]);

            e = extent(obj.hTable);
            set(obj.hTable, 'Position', e);
            
            GuiLayout.ApplyLayout(obj.hPanel, {{obj.hTable, [0 0]}});
        end
    end % of private methods
end % of classdef
