classdef CFileSelect < handle
    %CFILESELECT NiHu.Lab class for file selection
    
    properties (SetAccess = immutable, GetAccess = private)
        Types = {'txt', 'mat'};
    end
    
    properties (SetObservable)
        FileName
        Directory
        iType = 1;
    end
    
    properties (Dependent)
        Type
    end
    
    methods
        function obj = CFileSelect(types)
            %CFILESELECT constructor
            
            obj.FileName = CBabel.getInstance().getText('UNTITLED');
            obj.Directory = pwd;
            if nargin == 1
                obj.Types = types;
            end
            obj.NextAvailable();
        end
        
        function DirSelect(obj)
            %DIRSELECT select a directory
            
            d = uigetdir(obj.Directory);
            if d ~= 0
                obj.Directory = d;
            end
        end
        
        function val = get.Type(obj)
            val = obj.Types{obj.iType};
        end
        
        function NextAvailable(obj)
            %NEXTAVAILABLE select next available file in the directory
            
            d = regexp(obj.FileName, '(?<name>\w+)_(?<num>\d+)', 'names');
            if ~isempty(d)
                name = d.name;
                num = str2double(d.num);
            else
                name = obj.FileName;
                num = 0;
            end
            while ~isempty(dir(fullfile(obj.Directory, sprintf('%s_%.3d.mat', name, num))))
                num = num+1;
            end
            obj.FileName = sprintf('%s_%.3d', name, num);
        end
        
        function SwitchType(obj)
            %SWITCHTYPE change file type
            
            obj.iType = mod(obj.iType, length(obj.Types))+1;
        end
        
        function fname = getFullFileName(obj)
            %GETFULLFILENAME return full file name
            
            fname = fullfile(obj.Directory, obj.FileName);
        end
    end % of methods
end % of class CFILESELECT
