classdef CLevelMeterView < CGuiView & CPanel
    %CLEVELMETER Class to measure channel signal levels
    
    properties (Access = private)
        hBar
        hAx
        
        MinLevel
        isBlocked
        
        listLanguageChange
    end
    
    methods
        function obj = CLevelMeterView(parent, hData, MinLevel)
            %CLEVELMETERVIEW constructor
            
            obj = obj@CPanel(parent, 'LEVELMETER_PANEL');
            obj = obj@CGuiView(hData, {'Levels', 'Peaks'});
            obj.MinLevel = MinLevel;
            obj.InitFigure();
            obj.isBlocked = false;
            obj.refresh();

            obj.listLanguageChange = addlistener(CBabel.getInstance(), 'currentLanguage', 'PostSet', @(src,event)languageChangeCallback(obj));
        end
        
        function delete(obj)
            %DELETE destructor
            
            delete(obj.listLanguageChange);
        end
        
        function languageChangeCallback(obj)
            %LANGUAGECHANGECALLBACK called when the language has changed
            
            ylabel(obj.hAx, sprintf('%s [dBFS + %d]', CBabel.getInstance().getText('PEAK_LEVEL'), obj.MinLevel));
        end
        
        function refresh(obj)
            %REFRESH function called when data object has changed

            ranges = obj.hData.Channels.getRange();
            levdB = 20*log10(obj.hData.Levels./ranges)+obj.MinLevel;
            peakdB = 20*log10(obj.hData.Peaks./ranges)+obj.MinLevel;
            levdB(levdB < 0) = nan;
            diffdB = peakdB-levdB;
            set(obj.hBar(1), 'YData', levdB);
            set(obj.hBar(2), 'YData', diffdB);
        end
        
        function ButtonDownFcn(obj)
            %BUTTONDOWNFCN called when the user clicks into the axis
            
            switch(get(gcbf, 'SelectionType'))
                case 'alt'
                    if ~obj.isBlocked
                        CMultiAmpSetter(obj.hData.Channels);
                    end
                case 'open' % double click (copy figure)
                    obj.hData.ResetPeaks();
                otherwise
            end
        end
        
        function block(obj)
            %BLOCK called when the user blocks the gui
            
            obj.isBlocked = true;
        end
        
        function unblock(obj)
            %UNBLOCK called when the user unblocks the gui
            
            obj.isBlocked = false;
        end
    end % of public methods

    methods (Access = private)
        function InitFigure(obj)
            nCh = length(obj.hData.Channels);
            obj.hAx = axes('Parent', obj.hPanel,...
                'NextPlot', 'ReplaceChildren', ...
                'yGrid', 'on', ...
                'ButtonDownFcn', @(src,event)ButtonDownFcn(obj));
            obj.hBar = bar(obj.hAx, zeros(nCh ,2), 'stacked');
            ylabel(obj.hAx, sprintf('%s [dBFS + %d]', CBabel.getInstance().getText('PEAK_LEVEL'), obj.MinLevel));
            set(obj.hBar(1), 'FaceColor', 'Yellow');
            set(obj.hBar(2), 'FaceColor', 'Red');
            xlim(obj.hAx, [.5, nCh+.5]);
            ylim(obj.hAx, [0, obj.MinLevel]);
            l = {{obj.hAx, [-1 -1]}};
            GuiLayout.ApplyLayout(obj.hPanel, l);
        end
    end % of private methods
end % of classdef
