classdef CModule < CDevice
    %CMODULE An input or output hardware module
    
    properties (SetAccess = immutable)
        nChannels   % number of channels
        nBits       % number of bits
        Range       % Range of module
        LSB         % LSB vector of module channels
        Offset      % Offset vector of module channels
        provideICP  % indicates whether module provides ICP load
        isInput     % indicates whether module is input or output
    end
    
    methods
        function obj = CModule(vendor, model, sn, nch, nbits, range, lsb, offset, provicp, isinput)
            obj = obj@CDevice(vendor, model, sn);
            obj.nChannels = nch;
            obj.nBits = nbits;
            obj.Range = range;
            obj.LSB = lsb;
            obj.Offset = offset;
            obj.provideICP = provicp;
            obj.isInput = isinput;
        end
        
        function r = getModel(obj)
            r = cell(size(obj));
            for i = 1 : numel(r)
                r{i} = obj(i).Model;
            end
        end
    end
    
    methods (Static)
        function m = FromSN(sn)
            m = enumeration('CModule');
            m = m(ismember(cell2mat({m.SerialNr}), sn));
        end
    end
    
    enumeration
        NI9215 ('National Instruments', 'NI9215', hex2dec('13D723E'), 4, 16, 10, [318430 315989 318510 316369]*1e-9, [-14301928 24544176 -11292846 2785937]*1e-9, false, true);
        NI9234a ('National Instruments', 'NI9234', hex2dec('1413E8D'), 4, 24,  5, [609951 609855 609724 610084]*1e-12, [-621052 -1294525 -25883 56568]*1e-9, true, true);
        NI9234b ('National Instruments', 'NI9234', hex2dec('14EABC9'), 4, 24,  5, [610721 609962 609596 610094]*1e-12, [96577 -497916 -2332284 370058]*1e-9, true, true);
        NI9234c ('National Instruments', 'NI9234', hex2dec('19A4D43'), 4, 24,  5, [610721 609962 609596 610094]*1e-12, [96577 -497916 -2332284 370058]*1e-9, true, true);
        NI9263a ('National Instruments', 'NI9263', hex2dec('13EAB20'), 4, 16, 10, [326236 326317 326164 326426]*1e-9, [-14020402 12302558 28819125 14335183]*1e-9, false, false);
        NI9263b ('National Instruments', 'NI9263', hex2dec('19AA19F'), 4, 16, 10, [326236 326317 326164 326426]*1e-9, [-14020402 12302558 28819125 14335183]*1e-9, false, false);
        TRIAL ('Company', 'Module', hex2dec('000000'), 5, 16, 10, [326236 326317 326164 326426 326426]*1e-9, [0 0 0 0 0], false, true);
        UA25I ('Edirol', 'UA-25 Input Module', hex2dec('000000'), 2, 24, 10, 2/2^24*ones(2,1), [0 0], false, true);
        UA25O ('Edirol', 'UA-25 Output Module', hex2dec('000000'), 2, 24, 10, 2/2^24*ones(2,1), [0 0], false, false);
        Audiogram3I ('Yamaha', 'Audiogram3 Input Module', hex2dec('0004B6'), 2, 24, 1, 2/2^24*ones(2,1), [0 0], false, true);
        Audiogram3O ('Yamaha', 'Audiogram3 Output Module', hex2dec('0004B6'), 2, 24, 1, 2/2^24*ones(2,1), [0 0], false, false);
        TrackerPreI ('Creative', 'E-MU Tracker Pre USB Input Module', hex2dec('000000'), 2, 24, 1, 2/2^24*ones(2,1), [0 0], false, true);
        TrackerPreO ('Creative', 'E-MU Tracker Pre USB Output Module', hex2dec('000000'), 2, 24, 1, 2/2^24*ones(2,1), [0 0], false, false);
        WinSoundO('Windows', 'Windows Sound Card', hex2dec('000000'), 2, 24, 1, 2/2^24*ones(2,1), [0 0], false, false);
        FirefaceI('RME', 'Fireface', hex2dec('000000'), 28, 24, 1, 2/2^24*ones(28,1), zeros(1,28), false, true);
        FirefaceO('RME', 'Fireface', hex2dec('000000'), 28, 24, 1, 2/2^24*ones(28,1), zeros(1,28), false, false);
    end
end
