classdef CTriggerView < CGuiView & CBlockablePanel
    %CTRIGGERVIEW View class of CTrigger
    
    properties
        hTable      % table handle where the information is stored
        hStatus     % button handle where the status info is stored
    end
    
    methods
        function obj = CTriggerView(parent, hData)
            obj = obj@CBlockablePanel(parent, 'TRIGGER_PANEL');
            obj = obj@CGuiView(hData, {'trigLevel', 'preTrigTime', 'status'});
            obj.InitObject();
            obj.refresh();
        end
        
        function refresh(obj)
            %REFRESH function called when data object has changed
            
            Data = {obj.hData.trigLevel, obj.hData.preTrigTime};
            CN = {'Trigger Level [V]', 'Pretrigger Time [s]'};
            CF = {'numeric', 'numeric'};
            set(obj.hTable, 'Data', Data, 'ColumnName', CN, 'ColumnFormat', CF);
            
            status = obj.hData.status;
            switch status
                case 'idle'
                    set(obj.hStatus, 'BackgroundColor', 'white', 'String', CBabel.getInstance().getText('IDLE'));
                case 'init'
                    set(obj.hStatus, 'BackgroundColor', 'red', 'String', CBabel.getInstance().getText('INITIALISING'));
                case 'armed'
                    set(obj.hStatus, 'BackgroundColor', 'green', 'String', CBabel.getInstance().getText('ARMED'));
                case 'measuring'
                    set(obj.hStatus, 'BackgroundColor', 'yellow', 'String', CBabel.getInstance().getText('MEASURING'));
            end
        end
        
        function TableCallback(obj)
            Data = get(obj.hTable, 'Data');
            obj.hData.trigLevel = Data{1};
            obj.hData.preTrigTime = Data{2};
        end
    end % of public methods
    
    methods (Access = private)
        function InitObject(obj)
            obj.hTable = uitable('Parent', obj.hPanel, 'RowName', [],...
                'Units', 'Pixels', 'ColumnWidth', {100 100}, ...
                'ColumnEditable', true(1,2), ...
                'CellEditCallback', @(src, event)TableCallback(obj), ...
                'Data', {1 2},...
                'Position', [0, 0, 100, 10]);

            e = extent(obj.hTable);
            set(obj.hTable, 'Position', e);
            
            obj.hStatus = uicontrol('Parent', obj.hPanel, ...
                'style', 'pushButton');
            
            GuiLayout.ApplyLayout(obj.hPanel, {{obj.hTable, [0 0]}; {obj.hStatus, [-1 0]}});
        end
    end % of private methods
end % of classdef
