classdef CameraStreamer
    properties
        Status
        Context
        Channels
        nCh
        CRIO
    end
    
    methods
        function obj = CameraStreamer(Channels, DataRate)
            obj.Channels = Channels(cell2mat({Channels.isSelected}));
            obj.nCh = length(Channels);
            obj.CRIO = CCRIO('rio://169.254.125.17/RIO0');
            [ChSel, OpMode] = FpgaChSelOpMode(Channels);
            S = obj.CRIO.acquireFPGA;
            S.open('norun');
            S.DataRate = DataRate;
            S.ChannelSelect = ChSel;
            S.OperationMode = OpMode;
            S.DMAInput.configure(2e6);
            [obj.Status, obj.Context] = S.reserveIrq;
            obj.Status = S.run('nowait');
            S.StopSegment = 0;
            S.stop = 0;
            S.AcquisitionMode = 1; % Continuous
        end
        
        function start(obj)
            S = obj.CRIO.acquireFPGA;
            [obj.Status, asserted, timedOut] = S.waitOnIrq(obj.Context, 15, Inf);
            obj.Status = S.ackIrq(asserted);
        end
        
        function [pressure, nRemaining] = readData(obj, nSamples)
            S = obj.CRIO.acquireFPGA;
            [obj.Status, Samples, nRemaining] = S.DMAInput.read(nSamples * obj.nCh, Inf);
            voltage = raw2calibrated(reshape(Samples, obj.nCh, nSamples)', obj.Channels);
            pressure = voltage * diag(1./cell2mat({obj.Channels.Sensitivity}));
        end
        
        function delete(obj)
            obj.Status = S.unreserveIrq(obj.Context);
            obj.Status = S.close;
        end
    end
end
