clear mex;
compile_mex();
copyfile NiHuDaQmx.mexw32 ../
clear;
close all;

device_name = 'cDAQ9184-19A3141';
input_channel_names = strcat(device_name, {
    'Mod1/ai0'
    'Mod1/ai1'
    'Mod1/ai2'
    'Mod1/ai3'
    'Mod2/ai0'
    'Mod2/ai1'
    'Mod2/ai2'
    'Mod2/ai3'
    });
output_channel_names = strcat(device_name, {
    'Mod3/ao0'
    'Mod3/ao1'
    'Mod3/ao2'
    'Mod3/ao3'
    'Mod4/ao0'
    'Mod4/ao1'
    'Mod4/ao2'
    'Mod4/ao3'
    });

fs = 51200/2;
nSamp = fs;
t = (0 : nSamp-1)' / fs;
f0 = 1000;

output = sin(2*pi*f0*t) * (1:8) / 4;

NiHuDAQmx('reserve_network_device', device_name);
prop = NiHuDAQmx('get_chassis_properties', device_name);
hin = NiHuDAQmx('create_task', 'csucsuInputTask');
hout = NiHuDAQmx('create_task', 'csucsuOutputTask');
try
    for i = 1 : length(input_channel_names)
        NiHuDAQmx('create_input_channel', hin, input_channel_names{i}, [-5 5], false);
    end
    
    for i = 1 : length(output_channel_names)
        NiHuDAQmx('create_output_channel', hout, output_channel_names{i}, [-5 5]);
    end
    
    NiHuDAQmx('configure_timing', [hin hout], fs, false, uint64(nSamp));
    
    n_written = NiHuDAQmx('write', hout, output);
    
    NiHuDAQmx('start_task', [hin hout]);
    [input, n_read] = NiHuDAQmx('read', hin, int32(nSamp));
    NiHuDAQmx('stop_task', [hin hout]);
catch ME
    disp(ME.message);
end
NiHuDAQmx('clear_task', [hin hout]);
NiHuDAQmx('unreserve_network_device', device_name);

figure;
plot(t, output, t, input, '.-');
xlim([0 10e-3]);
