function x = sweepsignal(type, flim, nSamples, fs)
%SWEEPSIGNAL  Sweep Sine Signal
%   X = SWEEPSIGNAL(TYPE, FLIM, NSAMP, FS)  generates a sweep sine signal
%   that sweeps the frequency range defined in the two element vector FLIM.
%   The signal has a sanmpling frequency FS and consists of NSAMP samples.
%   The TYPE parameter can be 'lin' for linear sweep and 'exp' for
%   exponential sweep.
%
% Example
%   x = sweepsignal('exp', [10 1000], 20000, 44100);
%   soundsc(x, 44100);
%
% See also MLSSIGNAL

% Copyright 2010-2011 Peter Fiala

try % mex version
    switch type
        case 'lin'
            x = sweepsignal_mex(0, double(flim), nSamples, fs);
        case 'exp'
            x = sweepsignal_mex(1, double(flim), nSamples, fs);
        otherwise
            error('sweep type should be ''lin'' or ''exp''');
    end
catch % matlab version
    flim = 2*pi*flim/fs;
    switch type
        case 'lin'
            f = linspace(flim(1), flim(2), nSamples)';
        case 'exp'
            f = logspace(log10(flim(1)), log10(flim(2)), nSamples)';
        otherwise
            error('sweep type should be ''lin'' or ''exp''');
    end
    x = sin(cumsum(f));
end
end